# Copyright (c) 2011 Cloudera, Inc. All rights reserved.

class JsonParser(object):
  def __init__(self, json_dict):
    """
    May raise ParseError if the json structure is not what
    we expect.
    """
    self.json = json_dict

# Collected from bolt CDH3 Master on 10/18/2012.
SAMPLE_CDH3 = r"""
{
   "hbase":{
      "info":[

      ],
      "master":[
         [
            {
               "Master":"centos62-25.ent.cloudera.com:60000",
               "hostName":"centos62-25.ent.cloudera.com"
            },
            {
               "cluster_requests":0.0,
               "splitSize_avg_time":0,
               "splitSize_num_ops":0,
               "splitTime_avg_time":0,
               "splitTime_num_ops":0
            }
         ]
      ]
   },
   "jvm":{
      "metrics":[
         [
            {
               "hostName":"centos62-25.ent.cloudera.com",
               "processName":"Master",
               "sessionId":"centos62-25.ent.cloudera.com:60000"
            },
            {
               "gcCount":873,
               "gcTimeMillis":2596,
               "logError":0,
               "logFatal":0,
               "logInfo":0,
               "logWarn":0,
               "maxMemoryM":300.25,
               "memHeapCommittedM":81.0625,
               "memHeapUsedM":21.48629,
               "memNonHeapCommittedM":46.976562,
               "memNonHeapUsedM":29.409744,
               "threadsBlocked":0,
               "threadsNew":0,
               "threadsRunnable":18,
               "threadsTerminated":0,
               "threadsTimedWaiting":12,
               "threadsWaiting":19
            }
         ]
      ]
   },
   "rpc":{
      "metrics":[
         [
            {
               "hostName":"centos62-25.ent.cloudera.com",
               "port":"60000"
            },
            {
               "RpcProcessingTime_avg_time":0,
               "RpcProcessingTime_num_ops":4,
               "RpcQueueTime_avg_time":0,
               "RpcQueueTime_num_ops":5,
               "RpcSlowResponse_avg_time":0,
               "RpcSlowResponse_num_ops":0,
               "addColumn.aboveOneSec._avg_time":0,
               "addColumn.aboveOneSec._num_ops":0,
               "addColumn_avg_time":0,
               "addColumn_num_ops":0,
               "assign.aboveOneSec._avg_time":0,
               "assign.aboveOneSec._num_ops":0,
               "assign_avg_time":0,
               "assign_num_ops":0,
               "balance.aboveOneSec._avg_time":0,
               "balance.aboveOneSec._num_ops":0,
               "balanceSwitch.aboveOneSec._avg_time":0,
               "balanceSwitch.aboveOneSec._num_ops":0,
               "balanceSwitch_avg_time":0,
               "balanceSwitch_num_ops":0,
               "balance_avg_time":0,
               "balance_num_ops":0,
               "bulkLoadHFile_avg_time":0,
               "bulkLoadHFile_num_ops":0,
               "bulkLoadHFiles_avg_time":0,
               "bulkLoadHFiles_num_ops":0,
               "checkAndDelete_avg_time":0,
               "checkAndDelete_num_ops":0,
               "checkAndPut_avg_time":0,
               "checkAndPut_num_ops":0,
               "closeRegion_avg_time":0,
               "closeRegion_num_ops":0,
               "close_avg_time":0,
               "close_num_ops":0,
               "compactRegion_avg_time":0,
               "compactRegion_num_ops":0,
               "createTable.aboveOneSec._avg_time":0,
               "createTable.aboveOneSec._num_ops":0,
               "createTable_avg_time":0,
               "createTable_num_ops":0,
               "deleteColumn.aboveOneSec._avg_time":0,
               "deleteColumn.aboveOneSec._num_ops":0,
               "deleteColumn_avg_time":0,
               "deleteColumn_num_ops":0,
               "deleteTable.aboveOneSec._avg_time":0,
               "deleteTable.aboveOneSec._num_ops":0,
               "deleteTable_avg_time":0,
               "deleteTable_num_ops":0,
               "delete_avg_time":0,
               "delete_num_ops":0,
               "disableTable.aboveOneSec._avg_time":0,
               "disableTable.aboveOneSec._num_ops":0,
               "disableTable_avg_time":0,
               "disableTable_num_ops":0,
               "enableTable.aboveOneSec._avg_time":0,
               "enableTable.aboveOneSec._num_ops":0,
               "enableTable_avg_time":0,
               "enableTable_num_ops":0,
               "exists_avg_time":0,
               "exists_num_ops":0,
               "flushRegion_avg_time":0,
               "flushRegion_num_ops":0,
               "getClosestRowBefore_avg_time":0,
               "getClosestRowBefore_num_ops":0,
               "getClusterStatus.aboveOneSec._avg_time":0,
               "getClusterStatus.aboveOneSec._num_ops":0,
               "getClusterStatus_avg_time":0,
               "getClusterStatus_num_ops":13287,
               "getCompactionState_avg_time":0,
               "getCompactionState_num_ops":0,
               "getHServerInfo_avg_time":0,
               "getHServerInfo_num_ops":0,
               "getOnlineRegions_avg_time":0,
               "getOnlineRegions_num_ops":0,
               "getProtocolVersion.aboveOneSec._avg_time":0,
               "getProtocolVersion.aboveOneSec._num_ops":0,
               "getProtocolVersion_avg_time":0,
               "getProtocolVersion_num_ops":4065,
               "getRegionInfo_avg_time":0,
               "getRegionInfo_num_ops":0,
               "get_avg_time":0,
               "get_num_ops":0,
               "incrementColumnValue_avg_time":0,
               "incrementColumnValue_num_ops":0,
               "increment_avg_time":0,
               "increment_num_ops":0,
               "isMasterRunning.aboveOneSec._avg_time":0,
               "isMasterRunning.aboveOneSec._num_ops":0,
               "isMasterRunning_avg_time":0,
               "isMasterRunning_num_ops":26573,
               "lockRow_avg_time":0,
               "lockRow_num_ops":0,
               "modifyColumn.aboveOneSec._avg_time":0,
               "modifyColumn.aboveOneSec._num_ops":0,
               "modifyColumn_avg_time":0,
               "modifyColumn_num_ops":0,
               "modifyTable.aboveOneSec._avg_time":0,
               "modifyTable.aboveOneSec._num_ops":0,
               "modifyTable_avg_time":0,
               "modifyTable_num_ops":0,
               "move.aboveOneSec._avg_time":0,
               "move.aboveOneSec._num_ops":0,
               "move_avg_time":0,
               "move_num_ops":0,
               "multiPut_avg_time":0,
               "multiPut_num_ops":0,
               "multi_avg_time":0,
               "multi_num_ops":0,
               "next_avg_time":0,
               "next_num_ops":0,
               "offline.aboveOneSec._avg_time":0,
               "offline.aboveOneSec._num_ops":0,
               "offline_avg_time":0,
               "offline_num_ops":0,
               "openRegion_avg_time":0,
               "openRegion_num_ops":0,
               "openRegions_avg_time":0,
               "openRegions_num_ops":0,
               "openScanner_avg_time":0,
               "openScanner_num_ops":0,
               "put_avg_time":0,
               "put_num_ops":0,
               "regionServerReport.aboveOneSec._avg_time":0,
               "regionServerReport.aboveOneSec._num_ops":0,
               "regionServerReport_avg_time":0,
               "regionServerReport_num_ops":1062648,
               "regionServerStartup.aboveOneSec._avg_time":0,
               "regionServerStartup.aboveOneSec._num_ops":0,
               "regionServerStartup_avg_time":0,
               "regionServerStartup_num_ops":4,
               "replicateLogEntries_avg_time":0,
               "replicateLogEntries_num_ops":0,
               "reportRSFatalError.aboveOneSec._avg_time":0,
               "reportRSFatalError.aboveOneSec._num_ops":0,
               "reportRSFatalError_avg_time":0,
               "reportRSFatalError_num_ops":0,
               "shutdown.aboveOneSec._avg_time":0,
               "shutdown.aboveOneSec._num_ops":0,
               "shutdown_avg_time":0,
               "shutdown_num_ops":0,
               "splitRegion_avg_time":0,
               "splitRegion_num_ops":0,
               "stopMaster.aboveOneSec._avg_time":0,
               "stopMaster.aboveOneSec._num_ops":0,
               "stopMaster_avg_time":0,
               "stopMaster_num_ops":0,
               "unassign.aboveOneSec._avg_time":0,
               "unassign.aboveOneSec._num_ops":0,
               "unassign_avg_time":0,
               "unassign_num_ops":0,
               "unlockRow_avg_time":0,
               "unlockRow_num_ops":0
            }
         ]
      ]
   }
}
"""

# Collected from bolt CDH4 Master on 10/18/2012.
SAMPLE_CDH4 = r"""
{
   "hbase":{
      "info":[

      ],
      "master":[
         [
            {
               "Master":"c0805.hal.cloudera.com,6000,1350437233705",
               "hostName":"c0805.hal.cloudera.com"
            },
            {
               "cluster_requests":77.2,
               "splitSize_avg_time":205843929,
               "splitSize_num_ops":1,
               "splitTime_avg_time":4810,
               "splitTime_num_ops":1
            }
         ]
      ]
   },
   "jvm":{
      "metrics":[
         [
            {
               "hostName":"c0805.hal.cloudera.com",
               "processName":"Master",
               "sessionId":"c0805.hal.cloudera.com,6000,1350437233705"
            },
            {
               "gcCount":4589,
               "gcTimeMillis":10954,
               "logError":0,
               "logFatal":0,
               "logInfo":0,
               "logWarn":0,
               "maxMemoryM":1011.25,
               "memHeapCommittedM":81.0625,
               "memHeapUsedM":20.940193,
               "memNonHeapCommittedM":68.78516,
               "memNonHeapUsedM":43.377716,
               "threadsBlocked":0,
               "threadsNew":0,
               "threadsRunnable":18,
               "threadsTerminated":0,
               "threadsTimedWaiting":11,
               "threadsWaiting":37
            }
         ]
      ]
   },
   "rpc":{
      "metrics":[
         [
            {
               "hostName":"c0805.hal.cloudera.com",
               "port":"6000"
            },
            {
               "NumOpenConnections":87,
               "ReceivedBytes":7837053740,
               "RpcProcessingTime_avg_time":0,
               "RpcProcessingTime_num_ops":4623483,
               "RpcQueueTime_avg_time":0,
               "RpcQueueTime_num_ops":4623483,
               "RpcSlowResponse_avg_time":0,
               "RpcSlowResponse_num_ops":0,
               "SentBytes":840316203,
               "addColumn.aboveOneSec._avg_time":0,
               "addColumn.aboveOneSec._num_ops":0,
               "addColumn_avg_time":0,
               "addColumn_num_ops":0,
               "assign.aboveOneSec._avg_time":0,
               "assign.aboveOneSec._num_ops":0,
               "assign_avg_time":0,
               "assign_num_ops":0,
               "balance.aboveOneSec._avg_time":0,
               "balance.aboveOneSec._num_ops":0,
               "balanceSwitch.aboveOneSec._avg_time":0,
               "balanceSwitch.aboveOneSec._num_ops":0,
               "balanceSwitch_avg_time":0,
               "balanceSwitch_num_ops":0,
               "balance_avg_time":0,
               "balance_num_ops":0,
               "bulkLoadHFiles_avg_time":0,
               "bulkLoadHFiles_num_ops":0,
               "callQueueLen":0,
               "checkAndDelete_avg_time":0,
               "checkAndDelete_num_ops":0,
               "checkAndPut_avg_time":0,
               "checkAndPut_num_ops":0,
               "closeRegion_avg_time":0,
               "closeRegion_num_ops":0,
               "close_avg_time":0,
               "close_num_ops":0,
               "compactRegion_avg_time":0,
               "compactRegion_num_ops":0,
               "createTable.aboveOneSec._avg_time":0,
               "createTable.aboveOneSec._num_ops":0,
               "createTable_avg_time":0,
               "createTable_num_ops":14,
               "deleteColumn.aboveOneSec._avg_time":0,
               "deleteColumn.aboveOneSec._num_ops":0,
               "deleteColumn_avg_time":0,
               "deleteColumn_num_ops":0,
               "deleteTable.aboveOneSec._avg_time":0,
               "deleteTable.aboveOneSec._num_ops":0,
               "deleteTable_avg_time":0,
               "deleteTable_num_ops":14,
               "delete_avg_time":0,
               "delete_num_ops":0,
               "disableTable.aboveOneSec._avg_time":0,
               "disableTable.aboveOneSec._num_ops":0,
               "disableTable_avg_time":0,
               "disableTable_num_ops":14,
               "enableTable.aboveOneSec._avg_time":0,
               "enableTable.aboveOneSec._num_ops":0,
               "enableTable_avg_time":0,
               "enableTable_num_ops":0,
               "execCoprocessor_avg_time":0,
               "execCoprocessor_num_ops":0,
               "exists_avg_time":0,
               "exists_num_ops":0,
               "flushRegion_avg_time":0,
               "flushRegion_num_ops":0,
               "getAlterStatus.aboveOneSec._avg_time":0,
               "getAlterStatus.aboveOneSec._num_ops":0,
               "getAlterStatus_avg_time":0,
               "getAlterStatus_num_ops":0,
               "getBlockCacheColumnFamilySummaries_avg_time":0,
               "getBlockCacheColumnFamilySummaries_num_ops":0,
               "getClosestRowBefore_avg_time":0,
               "getClosestRowBefore_num_ops":0,
               "getClusterStatus.aboveOneSec._avg_time":0,
               "getClusterStatus.aboveOneSec._num_ops":0,
               "getClusterStatus_avg_time":0,
               "getClusterStatus_num_ops":5272,
               "getCompactionState_avg_time":0,
               "getCompactionState_num_ops":0,
               "getHServerInfo_avg_time":0,
               "getHServerInfo_num_ops":0,
               "getHTableDescriptors.aboveOneSec._avg_time":0,
               "getHTableDescriptors.aboveOneSec._num_ops":0,
               "getHTableDescriptors_avg_time":0,
               "getHTableDescriptors_num_ops":40,
               "getOnlineRegions_avg_time":0,
               "getOnlineRegions_num_ops":0,
               "getProtocolSignature.aboveOneSec._avg_time":0,
               "getProtocolSignature.aboveOneSec._num_ops":0,
               "getProtocolSignature_avg_time":0,
               "getProtocolSignature_num_ops":0,
               "getProtocolVersion.aboveOneSec._avg_time":0,
               "getProtocolVersion.aboveOneSec._num_ops":0,
               "getProtocolVersion_avg_time":0,
               "getProtocolVersion_num_ops":1512,
               "getRegionInfo_avg_time":0,
               "getRegionInfo_num_ops":0,
               "get_avg_time":0,
               "get_num_ops":0,
               "incrementColumnValue_avg_time":0,
               "incrementColumnValue_num_ops":0,
               "increment_avg_time":0,
               "increment_num_ops":0,
               "isMasterRunning.aboveOneSec._avg_time":0,
               "isMasterRunning.aboveOneSec._num_ops":0,
               "isMasterRunning_avg_time":0,
               "isMasterRunning_num_ops":5998,
               "lockRow_avg_time":0,
               "lockRow_num_ops":0,
               "modifyColumn.aboveOneSec._avg_time":0,
               "modifyColumn.aboveOneSec._num_ops":0,
               "modifyColumn_avg_time":0,
               "modifyColumn_num_ops":0,
               "modifyTable.aboveOneSec._avg_time":0,
               "modifyTable.aboveOneSec._num_ops":0,
               "modifyTable_avg_time":0,
               "modifyTable_num_ops":0,
               "move.aboveOneSec._avg_time":0,
               "move.aboveOneSec._num_ops":0,
               "move_avg_time":0,
               "move_num_ops":0,
               "multi_avg_time":0,
               "multi_num_ops":0,
               "next_avg_time":0,
               "next_num_ops":0,
               "offline.aboveOneSec._avg_time":0,
               "offline.aboveOneSec._num_ops":0,
               "offline_avg_time":0,
               "offline_num_ops":0,
               "openRegion_avg_time":0,
               "openRegion_num_ops":0,
               "openRegions_avg_time":0,
               "openRegions_num_ops":0,
               "openScanner_avg_time":0,
               "openScanner_num_ops":0,
               "put_avg_time":0,
               "put_num_ops":0,
               "regionServerReport.aboveOneSec._avg_time":0,
               "regionServerReport.aboveOneSec._num_ops":0,
               "regionServerReport_avg_time":0,
               "regionServerReport_num_ops":4610478,
               "regionServerStartup.aboveOneSec._avg_time":0,
               "regionServerStartup.aboveOneSec._num_ops":0,
               "regionServerStartup_avg_time":0,
               "regionServerStartup_num_ops":138,
               "replicateLogEntries_avg_time":0,
               "replicateLogEntries_num_ops":0,
               "reportRSFatalError.aboveOneSec._avg_time":0,
               "reportRSFatalError.aboveOneSec._num_ops":0,
               "reportRSFatalError_avg_time":0,
               "reportRSFatalError_num_ops":3,
               "rollHLogWriter_avg_time":0,
               "rollHLogWriter_num_ops":0,
               "rpcAuthenticationFailures":0,
               "rpcAuthenticationSuccesses":0,
               "rpcAuthorizationFailures":0,
               "rpcAuthorizationSuccesses":0,
               "shutdown.aboveOneSec._avg_time":0,
               "shutdown.aboveOneSec._num_ops":0,
               "shutdown_avg_time":0,
               "shutdown_num_ops":0,
               "splitRegion_avg_time":0,
               "splitRegion_num_ops":0,
               "stopMaster.aboveOneSec._avg_time":0,
               "stopMaster.aboveOneSec._num_ops":0,
               "stopMaster_avg_time":0,
               "stopMaster_num_ops":0,
               "stop_avg_time":0,
               "stop_num_ops":0,
               "unassign.aboveOneSec._avg_time":0,
               "unassign.aboveOneSec._num_ops":0,
               "unassign_avg_time":0,
               "unassign_num_ops":0,
               "unlockRow_avg_time":0,
               "unlockRow_num_ops":0
            }
         ]
      ]
   }
}
"""

SAMPLE = SAMPLE_CDH4
